@@ -18,7 +18,7 @@ def group_activities(queryset):
     actions = OrderedDict()
     for item in queryset:
         # current is defined as within the past day.
-        if item.timestamp.date() >= datetime.datetime.now() - datetime.timedelta(days=1):
+        if item.timestamp >= datetime.datetime.now() - datetime.timedelta(days=1):
             current_item = True
         else:
             current_item = False
